@@ -390,7 +390,7 @@ class Database:
                     err_msg += error + ','
             print(err_msg)
 
-    def get_hk_buyback_by_code(self, code):
+    def get_hk_buyback_by_code(self, code, agg_value):
 
         link_url = 'http://www.hkfdb.net/data_api?'
         token_str = 'token=' + str(self.authToken)
@@ -406,6 +406,10 @@ class Database:
         df = df.set_index(keys='date')
         df = df.sort_index()
 
+        if agg_value == True:
+            df = df[['value']]
+            df = df.groupby(df.index).agg({'value': sum})
+
         return df
 
     def get_hk_buyback_by_date(self, start_date, end_date):
